==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/Mime/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Mime Module Reference", "index.html", [
    [ "Mime Module", "index.html", [
      [ "Introduction to the Mime Module", "index.html#mimeintro", null ],
      [ "Release Notes", "index.html#mimereleasenotes", [
        [ ".2 v1.4.2", "index.html#mime_1_4", null ],
        [ "v1.4.1", "index.html#mime_1_4_1", null ],
        [ "v1.3.4.1", "index.html#mime_1_3_4_1", null ],
        [ "v1.3.4", "index.html#mime_1_3_4", null ],
        [ "v1.3.3", "index.html#mime_1_3_3", null ],
        [ "v1.3.2", "index.html#mime_1_3_2", null ],
        [ "v1.3.1", "index.html#mime_1_3_1", null ],
        [ "v1.3", "index.html#mime_1_3", null ],
        [ "v1.2.1", "index.html#mime_1_2_1", null ],
        [ "v1.2", "index.html#mime_1_2", null ],
        [ "v1.1", "index.html#mime_1_1", null ],
        [ "v1.0", "index.html#mime_1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__astparser__symbol__usage__kind__constants.html#gaf0707423d219c01e2889e467380bda58",
"group__digest__algorithms.html#ga4860ea19cda90914fe06346d12db9564",
"group__filesystem__functions.html#ga834e1f95eb108bd6e4d564daecd68eda",
"group__math__functions.html#gaef73d17beb9f264c4563d82a620ea4b2",
"group__parse__options.html#ga77d54a192aeae13bac95700ab5bbb190",
"group__system__and__build__constants.html#gaf309af16653ccf009d207a851a3bc40f",
"struct_mime_1_1_form_data_message_info.html#a8c013429ec2ca5b45656fab2fd589660"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.4.1.tar.bz2: qore-0.9.4.1/docs/modules/Mime/html/navtreedata.js <==
/*
@licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2019 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of version 2 of the GNU General Public License as published by
the Free Software Foundation

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Mime Module Reference", "index.html", [
    [ "Mime Module", "index.html", [
      [ "Introduction to the Mime Module", "index.html#mimeintro", null ],
      [ "Release Notes", "index.html#mimereleasenotes", [
        [ ".2 v1.4.2", "index.html#mime_1_4", null ],
        [ "v1.4.1", "index.html#mime_1_4_1", null ],
        [ "v1.3.4.1", "index.html#mime_1_3_4_1", null ],
        [ "v1.3.4", "index.html#mime_1_3_4", null ],
        [ "v1.3.3", "index.html#mime_1_3_3", null ],
        [ "v1.3.2", "index.html#mime_1_3_2", null ],
        [ "v1.3.1", "index.html#mime_1_3_1", null ],
        [ "v1.3", "index.html#mime_1_3", null ],
        [ "v1.2.1", "index.html#mime_1_2_1", null ],
        [ "v1.2", "index.html#mime_1_2", null ],
        [ "v1.1", "index.html#mime_1_1", null ],
        [ "v1.0", "index.html#mime_1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#gac8e561799a9f873502e161695670c06d",
"group__file__seek__constants.html#gafb10f9061ee15381748299f4148b5839",
"group__math__functions.html#ga40e4696269395eca51826018ccb1005c",
"group__option__constants.html#gaac007b653cdc3acf169c9cc76ce4a928",
"group__string__functions.html#gab998e345a65c1e98ca9370c3a324f9cb",
"group__x509__verification__constants.html#ga78a4220220d45411835ef8601b8294bb"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
